<?php

/*
Plugin Name: Playboard Android Channel Widget
Plugin URI: http://playboard.me/widgets
Description:
Version: 1.0
Author: Playboard team
Author URI: http://playboard.me
*/
define( 'PB_PLUGIN_PATH', plugin_dir_path(__FILE__) );

class PlayboardChannelWidget extends WP_Widget
{


    static $add_script = TRUE;

    /**
     * Register widget with WordPress.
     */
    public function __construct() {

        $self = parent::WP_Widget(false, $name = 'PlayboardChannelWidget');

        $widget_ops = array('description' => __('Display a Playboard Android Channel'), 'classname' => 'playboard_channel_widget');
        $this->WP_Widget('playboard_channel_widget', __('Playboard Channel Widget'), $widget_ops);

        if (!is_admin())
        {

            wp_enqueue_script('jquery');
            wp_enqueue_script('pb-js', plugin_dir_url( __FILE__  ) . 'pb_load_channel_widget_wp.js', array('jquery'), null, false);
            wp_enqueue_style('pb-css',   plugin_dir_url( __FILE__  ) . 'pb_widget_web.css', null, null, false);
            wp_enqueue_style('pb-cleanslate',   plugin_dir_url( __FILE__  ) . 'cleanslate.css', null, null, false);
        }

    }

    function widget($args, $instance)
    {

        if (isset($instance['error']) && $instance['error'])
            return;

        extract($args);

        $ref = $instance['channel_id'];
        $channel_id = NULL;
        //parse the url
        if (strpos($ref, 'http://') === 0 || strpos($ref, 'http://') === 0) {
            $parsed = parse_url($ref);
            if ($parsed !== FALSE) {
                $path = $parsed['path'];
                $path_parts = explode('/', $path);
                if (count($path_parts) > 2 && $path_parts[1] == 'channel') {
                    $channel_id = $path_parts[2];
                }
            }
        }
        //just take the id
        if (is_null($channel_id)){
            $channel_id = $ref;
        }

        $width = $instance['width'];
        if (intval($width) < 240) {
            $width = 240;
        }

        $url = 'http://playboard.me/channel/' . $channel_id;

        echo '<span style="width: ' . $width . 'px !important" data-width=' . $width .' class="pb-channel"><a href="' . $url . '">Playboard Android Channel</a></span>';

    }

    function form($instance)
    {

        $width = esc_attr($instance['width']);
        if (intval($width) < 240) {
            $width = 240;
        }

        $channel_id = esc_attr($instance['channel_id']);

        ?>

    <p><label for="<?php echo $this->get_field_id('how_to'); ?>"><?php _e('How To Use:'); ?></label>
         <ol>
           <li>
              Go to <a href="http://playboard.me/" target="_blank">http://playboard.me</a>
           </li>
            <li>
               Find or create a channel
            </li>
            <li>
                Copy the channel URL or channel ID
            </li>

        </ol>
    </p>

    <p><label for="<?php echo $this->get_field_id('channel_id'); ?>"><?php _e('Playboard Channel URL or ID:'); ?></label>
        <input id="<?php echo $this->get_field_id('channel_id'); ?>" name="<?php echo $this->get_field_name('channel_id'); ?>"
               type="text" value="<?php echo $channel_id; ?>"/></p>

    <p><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Widget Width (in px):'); ?></label>
        <input id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>"
               type="text" value="<?php echo $width; ?>"/></p>


    <?php
    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['width'] = strip_tags($new_instance['width']);
        $instance['channel_id'] = strip_tags($new_instance['channel_id']);
        $instance['lang'] = strip_tags($new_instance['lang']);

        return $instance;
    }

}

add_action('widgets_init', create_function('', 'return register_widget("PlayboardChannelWidget");'));
